/*
  Java gfx-test framework

   Copyright (C) 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Graphics2D;



import org.gfxtest.framework.CommonRenderingStyles;
import org.gfxtest.framework.CommonShapesRenderer;
import org.gfxtest.framework.PrintTest;
import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;



/**
 * This test renders filled shapes using TexturePaint.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.PRINT_TEST)
@RenderStyle(RenderStyles.FILL)
@Transformation(Transformations.NONE)
@Zoom(1)
public class PrintTestTexturePaint extends PrintTest
{
    
    /**
     * Test if circle drawn by graphics.drawOval() is rendered correctly.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // draw the circle
        CommonShapesRenderer.drawCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Texture paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTexturePaintUsingCheckerTexture(TestImage image, Graphics2D graphics)
    {
        // set stroke color (it could not be used during the shape rendering)
        CommonRenderingStyles.setStrokeColor(graphics);
        // set texture
        CommonRenderingStyles.setTextureFillUsingCheckerTexture(image, graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Texture paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTexturePaintUsingDiagonalCheckerTexture(TestImage image, Graphics2D graphics)
    {
        // set stroke color (it could not be used during the shape rendering)
        CommonRenderingStyles.setStrokeColor(graphics);
        // set texture
        CommonRenderingStyles.setTextureFillUsingDiagonalCheckerTexture(image, graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Texture paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTexturePaintUsingGridTexture(TestImage image, Graphics2D graphics)
    {
        // set stroke color (it could not be used during the shape rendering)
        CommonRenderingStyles.setStrokeColor(graphics);
        // set texture
        CommonRenderingStyles.setTextureFillUsingGridTexture(image, graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Texture paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTexturePaintUsingDiagonalGridTexture(TestImage image, Graphics2D graphics)
    {
        // set stroke color (it could not be used during the shape rendering)
        CommonRenderingStyles.setStrokeColor(graphics);
        // set texture
        CommonRenderingStyles.setTextureFillUsingDiagonalGridTexture(image, graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Texture paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTexturePaintUsingHorizontalStripesTexture(TestImage image, Graphics2D graphics)
    {
        // set stroke color (it could not be used during the shape rendering)
        CommonRenderingStyles.setStrokeColor(graphics);
        // set texture
        CommonRenderingStyles.setTextureFillUsingHorizontalStripesTexture(image, graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Texture paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTexturePaintUsingVerticalStripesTexture(TestImage image, Graphics2D graphics)
    {
        // set stroke color (it could not be used during the shape rendering)
        CommonRenderingStyles.setStrokeColor(graphics);
        // set texture
        CommonRenderingStyles.setTextureFillUsingVerticalStripesTexture(image, graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Texture paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTexturePaintUsingHorizontalColorStripesTexture(TestImage image, Graphics2D graphics)
    {
        // set stroke color (it could not be used during the shape rendering)
        CommonRenderingStyles.setStrokeColor(graphics);
        // set texture
        CommonRenderingStyles.setTextureFillUsingHorizontalColorStripesTexture(image, graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Texture paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTexturePaintUsingVerticalColorStripesTexture(TestImage image, Graphics2D graphics)
    {
        // set stroke color (it could not be used during the shape rendering)
        CommonRenderingStyles.setStrokeColor(graphics);
        // set texture
        CommonRenderingStyles.setTextureFillUsingVerticalColorStripesTexture(image, graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Texture paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTexturePaintUsingDiagonalStripesTexture(TestImage image, Graphics2D graphics)
    {
        // set stroke color (it could not be used during the shape rendering)
        CommonRenderingStyles.setStrokeColor(graphics);
        // set texture
        CommonRenderingStyles.setTextureFillUsingDiagonalStripesTexture(image, graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Texture paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTexturePaintUsingDotTexture(TestImage image, Graphics2D graphics)
    {
        // set stroke color (it could not be used during the shape rendering)
        CommonRenderingStyles.setStrokeColor(graphics);
        // set texture
        CommonRenderingStyles.setTextureFillUsingColorDotsTexture(image, graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Texture paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTexturePaintUsingRGBTexture1(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture1(image, graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Texture paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTexturePaintUsingRGBTexture2(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture2(image, graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Texture paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleTexturePaintUsingRGBTexture3(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setTextureFillUsingRGBTexture3(image, graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Entry point to the test suite.
     * 
     * @param args
     *            not used in this case
     */
    public static void main(String[] args)
    {
        new PrintTestTexturePaint().runTestSuite(args);
    }
}

